summaryrefslogtreecommitdiff
path: root/checkers/__init__.py
diff options
context:
space:
mode:
Diffstat (limited to 'checkers/__init__.py')
-rw-r--r--checkers/__init__.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/checkers/__init__.py b/checkers/__init__.py
index dd868c6..cc95ea7 100644
--- a/checkers/__init__.py
+++ b/checkers/__init__.py
@@ -43,7 +43,7 @@ import warnings
from os import listdir
from os.path import dirname, join, isdir, splitext
-from logilab.astng.utils import ASTWalker
+from astroid.utils import ASTWalker
from logilab.common.modutils import load_module_from_file
from logilab.common.configuration import OptionsProviderMixIn
@@ -126,7 +126,7 @@ class BaseRawChecker(BaseChecker):
"use the ITokenChecker interface.",
DeprecationWarning)
stream = node.file_stream
- stream.seek(0) # XXX may be removed with astng > 0.23
+ stream.seek(0) # XXX may be removed with astroid > 0.23
self.process_tokens(tokenize.generate_tokens(stream.readline))
def process_tokens(self, tokens):